@@ -11,6 +11,10 @@ class TestDateTimeColumnExclusion(TestCase):
             id = sa.Column(sa.Integer, autoincrement=True, primary_key=True)
             name = sa.Column(sa.Unicode(255))
             created_at = sa.Column(sa.DateTime, default=datetime.now)
+            creation_date = sa.Column(
+                sa.Date, default=lambda: datetime.now().date
+            )
+            is_deleted = sa.Column(sa.Boolean, default=False)
 
         self.Article = Article
 
@@ -20,6 +24,18 @@ class TestDateTimeColumnExclusion(TestCase):
             self.Article.__versioned__['class'].__table__.c
         )
 
+    def test_date_columns_with_defaults_excluded_by_default(self):
+        assert (
+            'creation_date' not in
+            self.Article.__versioned__['class'].__table__.c
+        )
+
+    def test_datetime_exclusion_only_applies_to_datetime_types(self):
+        assert (
+            'is_deleted' in
+            self.Article.__versioned__['class'].__table__.c
+        )
+
 
 class TestDateTimeColumnInclusion(TestCase):
     def create_models(self):
